# CompNeuro Tools
My personal collection of tools for computational neuroscience. My PhD stuff

# Installation (Recommended)
I don't even consider building stuff for Windows anymore. Just use WSL2 if you're using Windows (I do).

1. Clone this repo
2. Install [uv](https://astral.sh/blog/uv)
3. Create a virtual environment in the repo folder with uv: `uv venv .venv` (minimum python version is 3.11)
4. Activate the virtual environment: `source .venv/bin/activate`
5. Install the dependencies: `uv sync`
6. Done :)